@@ -3,7 +3,7 @@
 #
 # Glances - An eye on your system
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -18,19 +18,10 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-"""Allow user to run Glances as a module from a dir or zip file."""
+"""Allow user to run Glances as a module."""
 
 # Execute with:
-# $ python glances/__main__.py (2.6)
-# $ python -m glances          (2.7+)
-
-import sys
-
-if __package__ is None and not hasattr(sys, "frozen"):
-    # It is a direct call to __main__.py
-    import os.path
-    path = os.path.realpath(os.path.abspath(__file__))
-    sys.path.append(os.path.dirname(os.path.dirname(path)))
+# $ python -m glances (2.7+)
 
 import glances
 
