@@ -4,6 +4,7 @@ var mainBowerFiles = require('main-bower-files');
 var ngAnnotate = require('gulp-ng-annotate');
 var templateCache = require('gulp-angular-templatecache');
 var del = require('del');
+var rename = require('gulp-rename');
 
 gulp.task('clean', function() {
   del('./public/*')
@@ -14,18 +15,20 @@ gulp.task('copy', function() {
     .pipe(gulp.dest('./public'));
 
   gulp.src('./css/*.css')
+    .pipe(rename({suffix: '.min'}))
     .pipe(gulp.dest('./public/css'));
 
   gulp.src('./images/*.png')
     .pipe(gulp.dest('./public/images'));
 
-  gulp.src('favicon.ico')
+  gulp.src('./images/favicon.ico')
     .pipe(gulp.dest('./public'));
 });
 
 gulp.task('bower', function() {
   return gulp.src(mainBowerFiles())
     .pipe(concat('vendor.js'))
+    .pipe(rename({suffix: '.min'}))
     .pipe(gulp.dest('./public/js'))
 });
 
@@ -33,12 +36,14 @@ gulp.task('build-js', function() {
   return gulp.src('./js/**/*.js')
     .pipe(ngAnnotate())
     .pipe(concat('main.js'))
+    .pipe(rename({suffix: '.min'}))
     .pipe(gulp.dest('./public/js'))
 });
 
 gulp.task('template', function () {
-  return gulp.src('./html/plugins/*.html')
-    .pipe(templateCache('templates.js', {'root': 'plugins/', 'module': 'glancesApp'}))
+  return gulp.src('./js/components/**/*.html')
+    .pipe(templateCache('templates.js', {'root': 'components/', 'module': 'glancesApp'}))
+    .pipe(rename({suffix: '.min'}))
     .pipe(gulp.dest('./public/js'));
 });
 
