@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -21,10 +21,11 @@
 
 import operator
 
+from glances.compat import u
+from glances.plugins.glances_plugin import GlancesPlugin
+
 import psutil
 
-from glances.plugins.glances_plugin import GlancesPlugin
-from glances.core.glances_logging import logger
 
 # SNMP OID
 # The snmpd.conf needs to be edited.
@@ -59,20 +60,21 @@ snmp_oid['esxi'] = snmp_oid['windows']
 # Define the history items list
 # All items in this list will be historised if the --enable-history tag is set
 # 'color' define the graph color in #RGB format
-items_history_list = [{'name': 'percent', 'color': '#00FF00'}]
+items_history_list = [{'name': 'percent',
+                       'description': 'File system usage in percent',
+                       'color': '#00FF00'}]
 
 
 class Plugin(GlancesPlugin):
 
-    """Glances' file system plugin.
+    """Glances file system plugin.
 
     stats is a list
     """
 
     def __init__(self, args=None):
         """Init the plugin."""
-        GlancesPlugin.__init__(
-            self, args=args, items_history_list=items_history_list)
+        super(Plugin, self).__init__(args=args, items_history_list=items_history_list)
 
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -81,20 +83,21 @@ class Plugin(GlancesPlugin):
         self.reset()
 
     def get_key(self):
-        """Return the key of the list"""
+        """Return the key of the list."""
         return 'mnt_point'
 
     def reset(self):
         """Reset/init the stats."""
         self.stats = []
 
+    @GlancesPlugin._check_decorator
     @GlancesPlugin._log_result_decorator
     def update(self):
         """Update the FS stats using the input method."""
         # Reset the list
         self.reset()
 
-        if self.get_input() == 'local':
+        if self.input_method == 'local':
             # Update stats using the standard system lib
 
             # Grab the stats using the PsUtil disk_partitions
@@ -105,12 +108,20 @@ class Plugin(GlancesPlugin):
             except UnicodeDecodeError:
                 return self.stats
 
+            # Optionnal hack to allow logicals mounts points (issue #448)
+            # Ex: Had to put 'allow=zfs' in the [fs] section of the conf file
+            #     to allow zfs monitoring
+            for fstype in self.get_conf_value('allow'):
+                try:
+                    fs_stat += [f for f in psutil.disk_partitions(all=True) if f.fstype.find(fstype) >= 0]
+                except UnicodeDecodeError:
+                    return self.stats
+
             # Loop over fs
             for fs in fs_stat:
-                fs_current = {}
-                fs_current['device_name'] = fs.device
-                fs_current['fs_type'] = fs.fstype
-                fs_current['mnt_point'] = fs.mountpoint
+                # Do not take hidden file system into account
+                if self.is_hide(fs.mountpoint):
+                    continue
                 # Grab the disk usage
                 try:
                     fs_usage = psutil.disk_usage(fs.mountpoint)
@@ -118,71 +129,71 @@ class Plugin(GlancesPlugin):
                     # Correct issue #346
                     # Disk is ejected during the command
                     continue
-                fs_current['size'] = fs_usage.total
-                fs_current['used'] = fs_usage.used
-                fs_current['free'] = fs_usage.total - fs_usage.used
-                fs_current['percent'] = fs_usage.percent
-                fs_current['key'] = self.get_key()
+                fs_current = {
+                    'device_name': fs.device,
+                    'fs_type': fs.fstype,
+                    # Manage non breaking space (see issue #1065)
+                    'mnt_point': u(fs.mountpoint).replace(u'\u00A0', ' '),
+                    'size': fs_usage.total,
+                    'used': fs_usage.used,
+                    'free': fs_usage.free,
+                    'percent': fs_usage.percent,
+                    'key': self.get_key()}
                 self.stats.append(fs_current)
 
-        elif self.get_input() == 'snmp':
+        elif self.input_method == 'snmp':
             # Update stats using SNMP
 
             # SNMP bulk command to get all file system in one shot
             try:
-                fs_stat = self.set_stats_snmp(snmp_oid=snmp_oid[self.get_short_system_name()],
+                fs_stat = self.get_stats_snmp(snmp_oid=snmp_oid[self.short_system_name],
                                               bulk=True)
             except KeyError:
-                fs_stat = self.set_stats_snmp(snmp_oid=snmp_oid['default'],
+                fs_stat = self.get_stats_snmp(snmp_oid=snmp_oid['default'],
                                               bulk=True)
 
             # Loop over fs
-            if self.get_short_system_name() in ('windows', 'esxi'):
+            if self.short_system_name in ('windows', 'esxi'):
                 # Windows or ESXi tips
                 for fs in fs_stat:
-                    # Memory stats are grabed in the same OID table (ignore it)
+                    # Memory stats are grabbed in the same OID table (ignore it)
                     if fs == 'Virtual Memory' or fs == 'Physical Memory' or fs == 'Real Memory':
                         continue
-                    fs_current = {}
-                    fs_current['device_name'] = ''
-                    fs_current['mnt_point'] = fs.partition(' ')[0]
-                    fs_current['size'] = int(
-                        fs_stat[fs]['size']) * int(fs_stat[fs]['alloc_unit'])
-                    fs_current['used'] = int(
-                        fs_stat[fs]['used']) * int(fs_stat[fs]['alloc_unit'])
-                    fs_current['percent'] = float(
-                        fs_current['used'] * 100 / fs_current['size'])
-                    fs_current['key'] = self.get_key()
+                    size = int(fs_stat[fs]['size']) * int(fs_stat[fs]['alloc_unit'])
+                    used = int(fs_stat[fs]['used']) * int(fs_stat[fs]['alloc_unit'])
+                    percent = float(used * 100 / size)
+                    fs_current = {
+                        'device_name': '',
+                        'mnt_point': fs.partition(' ')[0],
+                        'size': size,
+                        'used': used,
+                        'percent': percent,
+                        'key': self.get_key()}
                     self.stats.append(fs_current)
             else:
-                # Default behavor
+                # Default behavior
                 for fs in fs_stat:
-                    fs_current = {}
-                    fs_current['device_name'] = fs_stat[fs]['device_name']
-                    fs_current['mnt_point'] = fs
-                    fs_current['size'] = int(fs_stat[fs]['size']) * 1024
-                    fs_current['used'] = int(fs_stat[fs]['used']) * 1024
-                    fs_current['percent'] = float(fs_stat[fs]['percent'])
-                    fs_current['key'] = self.get_key()
+                    fs_current = {
+                        'device_name': fs_stat[fs]['device_name'],
+                        'mnt_point': fs,
+                        'size': int(fs_stat[fs]['size']) * 1024,
+                        'used': int(fs_stat[fs]['used']) * 1024,
+                        'percent': float(fs_stat[fs]['percent']),
+                        'key': self.get_key()}
                     self.stats.append(fs_current)
 
-        # Update the history list
-        self.update_stats_history('mnt_point')
-
-        # Update the view
-        self.update_views()
-
         return self.stats
 
     def update_views(self):
-        """Update stats views"""
+        """Update stats views."""
         # Call the father's method
-        GlancesPlugin.update_views(self)
+        super(Plugin, self).update_views()
 
         # Add specifics informations
         # Alert
         for i in self.stats:
-            self.views[i[self.get_key()]]['used']['decoration'] = self.get_alert(i['used'], max=i['size'], header=i['mnt_point'])
+            self.views[i[self.get_key()]]['used']['decoration'] = self.get_alert(
+                i['used'], maximum=i['size'], header=i['mnt_point'])
 
     def msg_curse(self, args=None, max_width=None):
         """Return the dict to display in the curse interface."""
@@ -190,7 +201,7 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if stats exist and display plugin enable...
-        if not self.stats or args.disable_fs:
+        if not self.stats or self.is_disable():
             return ret
 
         # Max size for the fsname name
@@ -202,17 +213,17 @@ class Plugin(GlancesPlugin):
 
         # Build the string message
         # Header
-        msg = '{0:{width}}'.format(_("FILE SYS"), width=fsname_max_width)
+        msg = '{:{width}}'.format('FILE SYS', width=fsname_max_width)
         ret.append(self.curse_add_line(msg, "TITLE"))
         if args.fs_free_space:
-            msg = '{0:>7}'.format(_("Free"))
+            msg = '{:>7}'.format('Free')
         else:
-            msg = '{0:>7}'.format(_("Used"))
+            msg = '{:>7}'.format('Used')
         ret.append(self.curse_add_line(msg))
-        msg = '{0:>7}'.format(_("Total"))
+        msg = '{:>7}'.format('Total')
         ret.append(self.curse_add_line(msg))
 
-        # Disk list (sorted by name)
+        # Filesystem list (sorted by name)
         for i in sorted(self.stats, key=operator.itemgetter(self.get_key())):
             # New line
             ret.append(self.curse_new_line())
@@ -220,23 +231,22 @@ class Plugin(GlancesPlugin):
                 mnt_point = i['mnt_point'][-fsname_max_width + 1:]
             elif len(i['mnt_point']) + len(i['device_name'].split('/')[-1]) <= fsname_max_width - 3:
                 # If possible concatenate mode info... Glances touch inside :)
-                mnt_point = i['mnt_point'] + \
-                    ' (' + i['device_name'].split('/')[-1] + ')'
+                mnt_point = i['mnt_point'] + ' (' + i['device_name'].split('/')[-1] + ')'
             elif len(i['mnt_point']) > fsname_max_width:
                 # Cut mount point name if it is too long
                 mnt_point = '_' + i['mnt_point'][-fsname_max_width + 1:]
             else:
                 mnt_point = i['mnt_point']
-            msg = '{0:{width}}'.format(mnt_point, width=fsname_max_width)
+            msg = '{:{width}}'.format(mnt_point, width=fsname_max_width)
             ret.append(self.curse_add_line(msg))
             if args.fs_free_space:
-                msg = '{0:>7}'.format(self.auto_unit(i['free']))
+                msg = '{:>7}'.format(self.auto_unit(i['free']))
             else:
-                msg = '{0:>7}'.format(self.auto_unit(i['used']))
+                msg = '{:>7}'.format(self.auto_unit(i['used']))
             ret.append(self.curse_add_line(msg, self.get_views(item=i[self.get_key()],
                                                                key='used',
                                                                option='decoration')))
-            msg = '{0:>7}'.format(self.auto_unit(i['size']))
+            msg = '{:>7}'.format(self.auto_unit(i['size']))
             ret.append(self.curse_add_line(msg))
 
         return ret
