@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -21,7 +21,6 @@
 
 import os
 import socket
-import numbers
 
 from glances.compat import nativestr, range
 from glances.logger import logger
@@ -53,6 +52,8 @@ class Plugin(GlancesPlugin):
         """Reset/init the stats."""
         self.stats = []
 
+    @GlancesPlugin._check_decorator
+    @GlancesPlugin._log_result_decorator
     def update(self):
         """Update HDD stats using the input method."""
         # Reset stats
@@ -91,11 +92,15 @@ class GlancesGrabHDDTemp(object):
         # Reset the list
         self.reset()
 
-        # Only update if --disable-hddtemp is not set
-        if self.args is None or self.args.disable_hddtemp:
-            return
-
         # Fetch the data
+        # data = ("|/dev/sda|WDC WD2500JS-75MHB0|44|C|"
+        #         "|/dev/sdb|WDC WD2500JS-75MHB0|35|C|"
+        #         "|/dev/sdc|WDC WD3200AAKS-75B3A0|45|C|"
+        #         "|/dev/sdd|WDC WD3200AAKS-75B3A0|45|C|"
+        #         "|/dev/sde|WDC WD3200AAKS-75B3A0|43|C|"
+        #         "|/dev/sdf|???|ERR|*|"
+        #         "|/dev/sdg|HGST HTS541010A9E680|SLP|*|"
+        #         "|/dev/sdh|HGST HTS541010A9E680|UNK|*|")
         data = self.fetch()
 
         # Exit if no data
@@ -120,8 +125,12 @@ class GlancesGrabHDDTemp(object):
             temperature = fields[offset + 3]
             unit = nativestr(fields[offset + 4])
             hddtemp_current['label'] = device
-            # Temperature could be 'ERR' or 'SLP' (see issue#824)
-            hddtemp_current['value'] = float(temperature) if isinstance(temperature, numbers.Number) else temperature
+            try:
+                hddtemp_current['value'] = float(temperature)
+            except ValueError:
+                # Temperature could be 'ERR', 'SLP' or 'UNK' (see issue #824)
+                # Improper bytes/unicode in glances_hddtemp.py (see issue #887)
+                hddtemp_current['value'] = nativestr(temperature)
             hddtemp_current['unit'] = unit
             self.hddtemp_list.append(hddtemp_current)
 
@@ -133,9 +142,10 @@ class GlancesGrabHDDTemp(object):
             sck.connect((self.host, self.port))
             data = sck.recv(4096)
         except socket.error as e:
-            logger.warning("Can not connect to an HDDtemp server ({0}:{1} => {2})".format(self.host, self.port, e))
+            logger.debug("Cannot connect to an HDDtemp server ({}:{} => {})".format(self.host, self.port, e))
             logger.debug("Disable the HDDtemp module. Use the --disable-hddtemp to hide the previous message.")
-            self.args.disable_hddtemp = True
+            if self.args is not None:
+                self.args.disable_hddtemp = True
             data = ""
         finally:
             sck.close()
