@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -22,11 +22,11 @@
 import base64
 import operator
 
-import psutil
-
-from glances.core.glances_timer import getTimeSinceLastUpdate
+from glances.timer import getTimeSinceLastUpdate
 from glances.plugins.glances_plugin import GlancesPlugin
 
+import psutil
+
 # SNMP OID
 # http://www.net-snmp.org/docs/mibs/interfaces.html
 # Dict key = interface_name
@@ -37,20 +37,26 @@ snmp_oid = {'default': {'interface_name': '1.3.6.1.2.1.2.2.1.2',
 # Define the history items list
 # All items in this list will be historised if the --enable-history tag is set
 # 'color' define the graph color in #RGB format
-items_history_list = [{'name': 'rx', 'color': '#00FF00', 'y_unit': 'bit/s'},
-                      {'name': 'tx', 'color': '#FF0000', 'y_unit': 'bit/s'}]
+items_history_list = [{'name': 'rx',
+                       'description': 'Download rate per second',
+                       'color': '#00FF00',
+                       'y_unit': 'bit/s'},
+                      {'name': 'tx',
+                       'description': 'Upload rate per second',
+                       'color': '#FF0000',
+                       'y_unit': 'bit/s'}]
 
 
 class Plugin(GlancesPlugin):
 
-    """Glances' network Plugin.
+    """Glances network plugin.
 
     stats is a list
     """
 
     def __init__(self, args=None):
         """Init the plugin."""
-        GlancesPlugin.__init__(self, args=args, items_history_list=items_history_list)
+        super(Plugin, self).__init__(args=args, items_history_list=items_history_list)
 
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -59,13 +65,14 @@ class Plugin(GlancesPlugin):
         self.reset()
 
     def get_key(self):
-        """Return the key of the list"""
+        """Return the key of the list."""
         return 'interface_name'
 
     def reset(self):
         """Reset/init the stats."""
         self.stats = []
 
+    @GlancesPlugin._check_decorator
     @GlancesPlugin._log_result_decorator
     def update(self):
         """Update network stats using the input method.
@@ -75,7 +82,7 @@ class Plugin(GlancesPlugin):
         # Reset stats
         self.reset()
 
-        if self.get_input() == 'local':
+        if self.input_method == 'local':
             # Update stats using the standard system lib
 
             # Grab network interface stat using the PsUtil net_io_counter method
@@ -84,6 +91,15 @@ class Plugin(GlancesPlugin):
             except UnicodeDecodeError:
                 return self.stats
 
+            # New in PsUtil 3.0
+            # - import the interface's status (issue #765)
+            # - import the interface's speed (issue #718)
+            netstatus = {}
+            try:
+                netstatus = psutil.net_if_stats()
+            except (AttributeError, OSError):
+                pass
+
             # Previous network interface stats are stored in the network_old variable
             if not hasattr(self, 'network_old'):
                 # First call, we init the network_old var
@@ -100,38 +116,57 @@ class Plugin(GlancesPlugin):
                 # Loop over interfaces
                 network_new = netiocounters
                 for net in network_new:
+                    # Do not take hidden interface into account
+                    if self.is_hide(net):
+                        continue
                     try:
-                        # Try necessary to manage dynamic network interface
-                        netstat = {}
-                        netstat['interface_name'] = net
-                        netstat['time_since_update'] = time_since_update
-                        netstat['cumulative_rx'] = network_new[net].bytes_recv
-                        netstat['rx'] = (network_new[net].bytes_recv -
-                                         self.network_old[net].bytes_recv)
-                        netstat['cumulative_tx'] = network_new[net].bytes_sent
-                        netstat['tx'] = (network_new[net].bytes_sent -
-                                         self.network_old[net].bytes_sent)
-                        netstat['cumulative_cx'] = (netstat['cumulative_rx'] +
-                                                    netstat['cumulative_tx'])
-                        netstat['cx'] = netstat['rx'] + netstat['tx']
+                        cumulative_rx = network_new[net].bytes_recv
+                        cumulative_tx = network_new[net].bytes_sent
+                        cumulative_cx = cumulative_rx + cumulative_tx
+                        rx = cumulative_rx - self.network_old[net].bytes_recv
+                        tx = cumulative_tx - self.network_old[net].bytes_sent
+                        cx = rx + tx
+                        netstat = {
+                            'interface_name': net,
+                            'time_since_update': time_since_update,
+                            'cumulative_rx': cumulative_rx,
+                            'rx': rx,
+                            'cumulative_tx': cumulative_tx,
+                            'tx': tx,
+                            'cumulative_cx': cumulative_cx,
+                            'cx': cx}
                     except KeyError:
                         continue
                     else:
+                        # Optional stats (only compliant with PsUtil 3.0+)
+                        # Interface status
+                        try:
+                            netstat['is_up'] = netstatus[net].isup
+                        except (KeyError, AttributeError):
+                            pass
+                        # Interface speed in Mbps, convert it to bps
+                        # Can be always 0 on some OS
+                        try:
+                            netstat['speed'] = netstatus[net].speed * 1048576
+                        except (KeyError, AttributeError):
+                            pass
+
+                        # Finaly, set the key
                         netstat['key'] = self.get_key()
                         self.stats.append(netstat)
 
                 # Save stats to compute next bitrate
                 self.network_old = network_new
 
-        elif self.get_input() == 'snmp':
+        elif self.input_method == 'snmp':
             # Update stats using SNMP
 
             # SNMP bulk command to get all network interface in one shot
             try:
-                netiocounters = self.set_stats_snmp(snmp_oid=snmp_oid[self.get_short_system_name()],
+                netiocounters = self.get_stats_snmp(snmp_oid=snmp_oid[self.short_system_name],
                                                     bulk=True)
             except KeyError:
-                netiocounters = self.set_stats_snmp(snmp_oid=snmp_oid['default'],
+                netiocounters = self.get_stats_snmp(snmp_oid=snmp_oid['default'],
                                                     bulk=True)
 
             # Previous network interface stats are stored in the network_old variable
@@ -149,28 +184,36 @@ class Plugin(GlancesPlugin):
                 network_new = netiocounters
 
                 for net in network_new:
+                    # Do not take hidden interface into account
+                    if self.is_hide(net):
+                        continue
+
                     try:
-                        # Try necessary to manage dynamic network interface
-                        netstat = {}
                         # Windows: a tips is needed to convert HEX to TXT
                         # http://blogs.technet.com/b/networking/archive/2009/12/18/how-to-query-the-list-of-network-interfaces-using-snmp-via-the-ifdescr-counter.aspx
-                        if self.get_short_system_name() == 'windows':
+                        if self.short_system_name == 'windows':
                             try:
-                                netstat['interface_name'] = str(base64.b16decode(net[2:-2].upper()))
+                                interface_name = str(base64.b16decode(net[2:-2].upper()))
                             except TypeError:
-                                netstat['interface_name'] = net
+                                interface_name = net
                         else:
-                            netstat['interface_name'] = net
-                        netstat['time_since_update'] = time_since_update
-                        netstat['cumulative_rx'] = float(network_new[net]['cumulative_rx'])
-                        netstat['rx'] = (float(network_new[net]['cumulative_rx']) -
-                                         float(self.network_old[net]['cumulative_rx']))
-                        netstat['cumulative_tx'] = float(network_new[net]['cumulative_tx'])
-                        netstat['tx'] = (float(network_new[net]['cumulative_tx']) -
-                                         float(self.network_old[net]['cumulative_tx']))
-                        netstat['cumulative_cx'] = (netstat['cumulative_rx'] +
-                                                    netstat['cumulative_tx'])
-                        netstat['cx'] = netstat['rx'] + netstat['tx']
+                            interface_name = net
+
+                        cumulative_rx = float(network_new[net]['cumulative_rx'])
+                        cumulative_tx = float(network_new[net]['cumulative_tx'])
+                        cumulative_cx = cumulative_rx + cumulative_tx
+                        rx = cumulative_rx - float(self.network_old[net]['cumulative_rx'])
+                        tx = cumulative_tx - float(self.network_old[net]['cumulative_tx'])
+                        cx = rx + tx
+                        netstat = {
+                            'interface_name': interface_name,
+                            'time_since_update': time_since_update,
+                            'cumulative_rx': cumulative_rx,
+                            'rx': rx,
+                            'cumulative_tx': cumulative_tx,
+                            'tx': tx,
+                            'cumulative_cx': cumulative_cx,
+                            'cx': cx}
                     except KeyError:
                         continue
                     else:
@@ -180,36 +223,44 @@ class Plugin(GlancesPlugin):
                 # Save stats to compute next bitrate
                 self.network_old = network_new
 
-        # Update the history list
-        self.update_stats_history(self.get_key())
-
-        # Update the view
-        self.update_views()
-
         return self.stats
 
     def update_views(self):
-        """Update stats views"""
+        """Update stats views."""
         # Call the father's method
-        GlancesPlugin.update_views(self)
+        super(Plugin, self).update_views()
 
         # Add specifics informations
         # Alert
         for i in self.stats:
             ifrealname = i['interface_name'].split(':')[0]
-            self.views[i[self.get_key()]]['rx']['decoration'] = self.get_alert(int(i['rx'] // i['time_since_update'] * 8),
-                                                                               header=ifrealname + '_rx')
-            self.views[i[self.get_key()]]['tx']['decoration'] = self.get_alert(int(i['tx'] // i['time_since_update'] * 8),
-                                                                               header=ifrealname + '_tx')
+            # Convert rate in bps ( to be able to compare to interface speed)
+            bps_rx = int(i['rx'] // i['time_since_update'] * 8)
+            bps_tx = int(i['tx'] // i['time_since_update'] * 8)
+            # Decorate the bitrate with the configuration file thresolds
+            alert_rx = self.get_alert(bps_rx, header=ifrealname + '_rx')
+            alert_tx = self.get_alert(bps_tx, header=ifrealname + '_tx')
+            # If nothing is define in the configuration file...
+            # ... then use the interface speed (not available on all systems)
+            if alert_rx == 'DEFAULT' and 'speed' in i and i['speed'] != 0:
+                alert_rx = self.get_alert(current=bps_rx,
+                                          maximum=i['speed'],
+                                          header='rx')
+            if alert_tx == 'DEFAULT' and 'speed' in i and i['speed'] != 0:
+                alert_tx = self.get_alert(current=bps_tx,
+                                          maximum=i['speed'],
+                                          header='tx')
+            # then decorates
+            self.views[i[self.get_key()]]['rx']['decoration'] = alert_rx
+            self.views[i[self.get_key()]]['tx']['decoration'] = alert_tx
 
     def msg_curse(self, args=None, max_width=None):
         """Return the dict to display in the curse interface."""
-
         # Init the return message
         ret = []
 
         # Only process if stats exist and display plugin enable...
-        if not self.stats or args.disable_network:
+        if not self.stats or self.is_disable():
             return ret
 
         # Max size for the interface name
@@ -221,35 +272,35 @@ class Plugin(GlancesPlugin):
 
         # Build the string message
         # Header
-        msg = '{0:{width}}'.format(_("NETWORK"), width=ifname_max_width)
+        msg = '{:{width}}'.format('NETWORK', width=ifname_max_width)
         ret.append(self.curse_add_line(msg, "TITLE"))
         if args.network_cumul:
             # Cumulative stats
             if args.network_sum:
                 # Sum stats
-                msg = '{0:>14}'.format(_("Rx+Tx"))
+                msg = '{:>14}'.format('Rx+Tx')
                 ret.append(self.curse_add_line(msg))
             else:
                 # Rx/Tx stats
-                msg = '{0:>7}'.format(_("Rx"))
+                msg = '{:>7}'.format('Rx')
                 ret.append(self.curse_add_line(msg))
-                msg = '{0:>7}'.format(_("Tx"))
+                msg = '{:>7}'.format('Tx')
                 ret.append(self.curse_add_line(msg))
         else:
             # Bitrate stats
             if args.network_sum:
                 # Sum stats
-                msg = '{0:>14}'.format(_("Rx+Tx/s"))
+                msg = '{:>14}'.format('Rx+Tx/s')
                 ret.append(self.curse_add_line(msg))
             else:
-                msg = '{0:>7}'.format(_("Rx/s"))
+                msg = '{:>7}'.format('Rx/s')
                 ret.append(self.curse_add_line(msg))
-                msg = '{0:>7}'.format(_("Tx/s"))
+                msg = '{:>7}'.format('Tx/s')
                 ret.append(self.curse_add_line(msg))
         # Interface list (sorted by name)
         for i in sorted(self.stats, key=operator.itemgetter(self.get_key())):
-            # Do not display hidden interfaces
-            if self.is_hide(i['interface_name']):
+            # Do not display interface in down state (issue #765)
+            if ('is_up' in i) and (i['is_up'] is False):
                 continue
             # Format stats
             # Is there an alias for the interface name ?
@@ -260,42 +311,39 @@ class Plugin(GlancesPlugin):
             if len(ifname) > ifname_max_width:
                 # Cut interface name if it is too long
                 ifname = '_' + ifname[-ifname_max_width + 1:]
+
             if args.byte:
                 # Bytes per second (for dummy)
-                if args.network_cumul:
-                    rx = self.auto_unit(int(i['cumulative_rx']))
-                    tx = self.auto_unit(int(i['cumulative_tx']))
-                    sx = self.auto_unit(int(i['cumulative_tx'])
-                                        + int(i['cumulative_tx']))
-                else:
-                    rx = self.auto_unit(int(i['rx'] // i['time_since_update']))
-                    tx = self.auto_unit(int(i['tx'] // i['time_since_update']))
-                    sx = self.auto_unit(int(i['rx'] // i['time_since_update'])
-                                        + int(i['tx'] // i['time_since_update']))
+                to_bit = 1
+                unit = ''
             else:
                 # Bits per second (for real network administrator | Default)
-                if args.network_cumul:
-                    rx = self.auto_unit(int(i['cumulative_rx'] * 8)) + "b"
-                    tx = self.auto_unit(int(i['cumulative_tx'] * 8)) + "b"
-                    sx = self.auto_unit(int(i['cumulative_rx'] * 8)
-                                        + int(i['cumulative_tx'] * 8)) + "b"
-                else:
-                    rx = self.auto_unit(int(i['rx'] // i['time_since_update'] * 8)) + "b"
-                    tx = self.auto_unit(int(i['tx'] // i['time_since_update'] * 8)) + "b"
-                    sx = self.auto_unit(int(i['rx'] // i['time_since_update'] * 8) +
-                                        int(i['tx'] // i['time_since_update'] * 8)) + "b"
+                to_bit = 8
+                unit = 'b'
+
+            if args.network_cumul:
+                rx = self.auto_unit(int(i['cumulative_rx'] * to_bit)) + unit
+                tx = self.auto_unit(int(i['cumulative_tx'] * to_bit)) + unit
+                sx = self.auto_unit(int(i['cumulative_rx'] * to_bit) +
+                                    int(i['cumulative_tx'] * to_bit)) + unit
+            else:
+                rx = self.auto_unit(int(i['rx'] // i['time_since_update'] * to_bit)) + unit
+                tx = self.auto_unit(int(i['tx'] // i['time_since_update'] * to_bit)) + unit
+                sx = self.auto_unit(int(i['rx'] // i['time_since_update'] * to_bit) +
+                                    int(i['tx'] // i['time_since_update'] * to_bit)) + unit
+
             # New line
             ret.append(self.curse_new_line())
-            msg = '{0:{width}}'.format(ifname, width=ifname_max_width)
+            msg = '{:{width}}'.format(ifname, width=ifname_max_width)
             ret.append(self.curse_add_line(msg))
             if args.network_sum:
-                msg = '{0:>14}'.format(sx)
+                msg = '{:>14}'.format(sx)
                 ret.append(self.curse_add_line(msg))
             else:
-                msg = '{0:>7}'.format(rx)
+                msg = '{:>7}'.format(rx)
                 ret.append(self.curse_add_line(
                     msg, self.get_views(item=i[self.get_key()], key='rx', option='decoration')))
-                msg = '{0:>7}'.format(tx)
+                msg = '{:>7}'.format(tx)
                 ret.append(self.curse_add_line(
                     msg, self.get_views(item=i[self.get_key()], key='tx', option='decoration')))
 
