@@ -3,7 +3,7 @@
 #
 # Glances - An eye on your system
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -182,6 +182,14 @@ class TestGlances(unittest.TestCase):
         req = json.loads(client.getIrq())
         self.assertIsInstance(req, list)
 
+    def test_013_plugin_views(self):
+        """Plugin views."""
+        method = "getViewsCpu()"
+        print('INFO: [TEST_013] Method: %s' % method)
+
+        req = json.loads(client.getViewsCpu())
+        self.assertIsInstance(req, dict)
+
     def test_999_stop_server(self):
         """Stop the Glances Web Server."""
         print('INFO: [TEST_999] Stop the Glances Server')
@@ -192,5 +200,6 @@ class TestGlances(unittest.TestCase):
 
         self.assertTrue(True)
 
+
 if __name__ == '__main__':
     unittest.main()
